---
name: Bug Report
about: Describe a bug or anything else that seems wrong
title: ''
labels: 'bug'

---

**Background**
Give some context for how you encountered the problem. What were you doing?

**Summary of the problem**
A clear and concise description of the problem that seems to be happening.

**Expected behaviour**
What did you expect to happen instead?

**Reproduction**
Are you able to reproduce the error or is it intermittent? Which version of ruru
are you using? Which operating system are you using?
